@@ -2,7 +2,8 @@
 # conflicts() in [R] base.
 .conflicts.OK <- TRUE 
 
-.First.lib <- function(libname, pkgname) {
+## .First.lib <- function(libname, pkgname) {
+.onAttach <- function(libname, pkgname) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Set up RCC validators for R.methodsS3.
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -19,3 +20,4 @@
   packageStartupMessage(pkgname, " v", pi$Version, " (", 
     pi$Date, ") successfully loaded. See ?", pkgname, " for help.");
 }
+
